@@ -51,23 +51,22 @@ test_settings_client (gpointer data)
         char    *strval;
         gboolean boolval;
         gboolean res;
-        guint    notify_id;
 
         strval = NULL;
         res = gdm_settings_client_get_string (GDM_KEY_WILLING, &strval);
         g_debug ("Got res=%d %s=%s", res, GDM_KEY_WILLING, strval);
         g_free (strval);
 
-        res = gdm_settings_client_get_boolean (GDM_KEY_XDMCP, &boolval);
-        g_debug ("Got res=%d %s=%s", res, GDM_KEY_XDMCP, boolval ? "true" : "false");
+        res = gdm_settings_client_get_boolean (GDM_KEY_XDMCP_ENABLE, &boolval);
+        g_debug ("Got res=%d %s=%s", res, GDM_KEY_XDMCP_ENABLE, boolval ? "true" : "false");
 
         g_debug ("Adding notify for all keys");
-        notify_id = gdm_settings_client_notify_add ("/", notify_cb, NULL, NULL);
+        gdm_settings_client_notify_add ("/", notify_cb, NULL, NULL);
 
-        g_debug ("Setting boolean key %s to %s", GDM_KEY_XDMCP, !boolval ? "true" : "false");
-        gdm_settings_client_set_boolean (GDM_KEY_XDMCP, !boolval);
-        g_debug ("Setting boolean key %s to %s", GDM_KEY_XDMCP, boolval ? "true" : "false");
-        gdm_settings_client_set_boolean (GDM_KEY_XDMCP, boolval);
+        g_debug ("Setting boolean key %s to %s", GDM_KEY_XDMCP_ENABLE, !boolval ? "true" : "false");
+        gdm_settings_client_set_boolean (GDM_KEY_XDMCP_ENABLE, !boolval);
+        g_debug ("Setting boolean key %s to %s", GDM_KEY_XDMCP_ENABLE, boolval ? "true" : "false");
+        gdm_settings_client_set_boolean (GDM_KEY_XDMCP_ENABLE, boolval);
 
         return FALSE;
 }
@@ -79,7 +78,7 @@ main (int argc, char **argv)
 
         g_type_init ();
 
-        if (! gdm_settings_client_init (GDMCONFDIR "/gdm.schemas", "/")) {
+        if (! gdm_settings_client_init (DATADIR "/gdm/gdm.schemas", "/")) {
                 exit (1);
         }
 
