@@ -469,7 +469,7 @@ update_item_for_user (GdmUserChooserWidget *widget,
         escaped_username = g_markup_escape_text (act_user_get_user_name (user), -1);
 
         real_name = act_user_get_real_name (user);
-        if (real_name == NULL || real_name == '\0') {
+        if (real_name == NULL || real_name[0] == '\0') {
                 real_name = act_user_get_user_name (user);
         }
         escaped_real_name = g_markup_escape_text (real_name, -1);
@@ -654,9 +654,30 @@ gdm_user_chooser_widget_set_show_user_auto (GdmUserChooserWidget *widget,
 char *
 gdm_user_chooser_widget_get_chosen_user_name (GdmUserChooserWidget *widget)
 {
+        char *active_item_id;
+        gboolean isnt_user;
+
         g_return_val_if_fail (GDM_IS_USER_CHOOSER_WIDGET (widget), NULL);
 
-        return gdm_chooser_widget_get_active_item (GDM_CHOOSER_WIDGET (widget));
+        active_item_id = gdm_chooser_widget_get_active_item (GDM_CHOOSER_WIDGET (widget));
+        if (active_item_id == NULL) {
+                g_debug ("GdmUserChooserWidget: no active item in list");
+                return NULL;
+        }
+
+        gdm_chooser_widget_lookup_item (GDM_CHOOSER_WIDGET (widget), active_item_id,
+                                        NULL, NULL, NULL, NULL, NULL,
+                                        &isnt_user);
+
+        if (isnt_user) {
+                g_debug ("GdmUserChooserWidget: active item '%s' isn't a user", active_item_id);
+                g_free (active_item_id);
+                return NULL;
+        }
+
+        g_debug ("GdmUserChooserWidget: active item '%s' is a user", active_item_id);
+
+        return active_item_id;
 }
 
 void
@@ -785,7 +806,7 @@ add_user (GdmUserChooserWidget *widget,
 
         escaped_username = g_markup_escape_text (act_user_get_user_name (user), -1);
         real_name = act_user_get_real_name (user);
-        if (real_name == NULL || real_name == '\0') {
+        if (real_name == NULL || real_name[0] == '\0') {
                 real_name = act_user_get_user_name (user);
         }
         escaped_real_name = g_markup_escape_text (real_name, -1);
@@ -1063,6 +1084,22 @@ gdm_user_chooser_widget_dispose (GObject *object)
         }
 
         if (widget->priv->manager != NULL) {
+                g_signal_handlers_disconnect_by_func (widget->priv->manager,
+                                                      G_CALLBACK (on_user_added),
+                                                      widget);
+                g_signal_handlers_disconnect_by_func (widget->priv->manager,
+                                                      G_CALLBACK (on_user_removed),
+                                                      widget);
+                g_signal_handlers_disconnect_by_func (widget->priv->manager,
+                                                      G_CALLBACK (on_is_loaded_changed),
+                                                      widget);
+                g_signal_handlers_disconnect_by_func (widget->priv->manager,
+                                                      G_CALLBACK (on_user_is_logged_in_changed),
+                                                      widget);
+                g_signal_handlers_disconnect_by_func (widget->priv->manager,
+                                                      G_CALLBACK (on_user_changed),
+                                                      widget);
+
                 g_object_unref (widget->priv->manager);
                 widget->priv->manager = NULL;
         }
